@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettings.py 11591 2019-05-29 06:14:02Z Andy $
+# $Id: AttachSettings.py 11595 2019-05-29 06:39:53Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-05-29 14:14:02 +0800 (週三, 29 五月 2019) $
-# $Revision: 11591 $
+# $Date: 2019-05-29 14:39:53 +0800 (週三, 29 五月 2019) $
+# $Revision: 11595 $
 
 import os
 
@@ -52,7 +52,10 @@ def attachSettings(settingsDict):
              'THEOPHRUSTUS_STATIC_DIRS',
              os.path.join(CURRENT_PATH, 'static')
              )    
-        staticDirs = list(settingsDict.get('STATICFILES_DIRS'))
+        if settingsDict.get('STATICFILES_DIRS') == None:
+            staticDirs = []
+        else:
+            staticDirs = list(settingsDict.get('STATICFILES_DIRS'))
         staticDirs.extend([THEOPHRUSTUS_STATIC_DIRS])
         settingsDict['STATICFILES_DIRS'] = tuple(staticDirs)
         
